@@ -11,7 +11,7 @@ from cubicweb.entities import AnyEntity, fetch_config
 class Tag(AnyEntity):
     """customized class for Tag entities"""
     __regid__ = 'Tag'
-    fetch_attrs, fetch_order = fetch_config(['name'])
+    fetch_attrs, cw_fetch_order = fetch_config(['name'])
 
     def closest_tags_rset(self):
         return self._cw.execute('Any CT, COUNT(X) GROUPBY CT ORDERBY 2 DESC '
