@@ -7,7 +7,7 @@
 __docformat__ = "restructuredtext en"
 
 from cubicweb.server.hook import Hook
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 
 class AddUpdateTagHook(Hook):
     """ensure tag names are lower case and commas are forbidden"""
