@@ -10,14 +10,13 @@ _ = unicode
 from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
-from cubicweb.selectors import (match_context_prop, match_kwargs,
-                                match_form_params, match_user_groups,
-                                has_related_entities, one_etype_rset,
-                                is_instance, relation_possible)
+from cubicweb.predicates import (match_kwargs, match_form_params,
+                                 match_user_groups,
+                                 has_related_entities, one_etype_rset,
+                                 is_instance, relation_possible)
 from cubicweb import uilib, tags
-from cubicweb.web import uicfg, stdmsgs, component, box, facet
-from cubicweb.web.htmlwidgets import BoxWidget, BoxHtml
-from cubicweb.web.views import baseviews, basecontrollers, xmlrss
+from cubicweb.web import stdmsgs, component, box, facet
+from cubicweb.web.views import baseviews, ajaxcontroller, xmlrss, uicfg
 
 
 _afs = uicfg.autoform_section
@@ -185,17 +184,16 @@ class TagsBox(component.AjaxEditRelationCtxComponent):
     fname_remove = 'untag_entity'
 
 
-@monkeypatch(basecontrollers.JSonController)
-@basecontrollers.jsonize
-def js_unrelated_tags(self, eid):
+@ajaxcontroller.ajaxfunc(output_type='json')
+def unrelated_tags(self, eid):
 
     """return tag unrelated to an entity"""
     rql = 'Any N ORDERBY N WHERE T is Tag, T name N, NOT T tags X, X eid %(x)s'
     return [name for (name,) in self._cw.execute(rql, {'x' : eid})]
 
 
-@monkeypatch(basecontrollers.JSonController)
-def js_tag_entity(self, eid, taglist):
+@ajaxcontroller.ajaxfunc
+def tag_entity(self, eid, taglist):
     execute = self._cw.execute
     # get list of tag for this entity
     tagged_by = set(tagname for (tagname,) in
@@ -213,8 +211,8 @@ def js_tag_entity(self, eid, taglist):
             rql = 'INSERT Tag T: T name %(name)s, T tags X WHERE X eid %(x)s'
             execute(rql, {'name' : tagname, 'x' : eid})
 
-@monkeypatch(basecontrollers.JSonController)
-def js_untag_entity(self, eid, tageid):
+@ajaxcontroller.ajaxfunc
+def untag_entity(self, eid, tageid):
     rql = 'DELETE T tags X WHERE T eid %(t)s, X eid %(x)s'
     self._cw.execute(rql, {'t': tageid, 'x' : eid})
 
@@ -229,9 +227,7 @@ class MergeComponent(component.EntityCtxComponent):
     title = _('merge tags')
 
     def render_body(self, w):
-        self._cw.add_js(('cubes.tag.merge.js', 'cubicweb.widgets.js',
-                         'jquery.autocomplete.js',))
-        self._cw.add_css('jquery.autocomplete.css')
+        self._cw.add_js(('cubes.tag.merge.js', 'cubicweb.widgets.js'))
         entity = self.entity
         w(u'<div id="tagmergeformholder%s">' % entity.eid)
         w(u'<h5>%s</h5>' % self._cw._('Enter a tag name'))
@@ -250,16 +246,14 @@ class MergeComponent(component.EntityCtxComponent):
         w(u'</div>')
 
 
-@monkeypatch(basecontrollers.JSonController)
-@basecontrollers.jsonize
-def js_unrelated_merge_tags(self, eid):
+@ajaxcontroller.ajaxfunc(output_type='json')
+def unrelated_merge_tags(self, eid):
     """return tag unrelated to an entity"""
     rql = 'Any N ORDERBY N WHERE T is Tag, T name N, NOT T eid %(x)s'
     return [name for (name,) in self._cw.execute(rql, {'x' : eid})]
 
-@monkeypatch(basecontrollers.JSonController)
-@basecontrollers.xhtmlize
-def js_tagged_entity_html(self, name):
+@ajaxcontroller.ajaxfunc(output_type='xhtml')
+def tagged_entity_html(self, name):
     rset = self._cw.execute('Any X ORDERBY X DESC LIMIT 10 WHERE T tags X, '
                             'T name %(x)s', {'x': name})
     html = []
@@ -276,9 +270,8 @@ def js_tagged_entity_html(self, name):
     return u' '.join(html)
 
 
-@monkeypatch(basecontrollers.JSonController)
-@basecontrollers.xhtmlize
-def js_merge_tags(self, eid, mergetag_name):
+@ajaxcontroller.ajaxfunc(output_type='xhtml')
+def merge_tags(self, eid, mergetag_name):
     mergetag_name = mergetag_name.strip(',') # XXX
     self._cw.execute('SET T tags X WHERE T1 tags X, NOT T tags X, '
                      'T eid %(x)s, T1 name %(name)s',
